@@ -129,6 +129,7 @@ read_h5sparse_component <- function(filepath, group, name,
                                       as.integer=as.integer))
 }
 
+### Returns a numeric vector (integer or double).
 .read_h5sparse_dim <- function(filepath, group)
 {
     if (h5exists(filepath, paste0(group, "/shape"))) {
@@ -145,7 +146,9 @@ read_h5sparse_component <- function(filepath, group, name,
                   "contains no 'shape' dataset and has no 'shape' ",
                   "or 'h5sparse_shape' attribute. As a consequence, the ",
                   "dimensions of the sparse matrix can't be determined."))
-    rev(as.integer(shape))
+    ## We pass 'shape' thru as.vector() to drop its class attribute in case
+    ## it's an array.
+    rev(as.vector(shape))
 }
 
 .read_h5sparse_format <- function(filepath, group)
@@ -265,6 +268,7 @@ H5SparseMatrixSeed <- function(filepath, group, subdata=NULL)
     ## Get matrix dimensions.
     dim <- .read_h5sparse_dim(filepath, group)
     stopifnot(length(dim) == 2L)
+    dim <- dim_as_integer(dim, filepath, group, what="sparse matrix")
 
     ## Get sparse format ("csc" or "csr").
     h5sparse_format <- .read_h5sparse_format(filepath, group)
